import {
  select,
  scaleLog,
  extent,
  axisLeft,
  axisBottom,
  format
} from 'd3';

export const scatterPlot = (selection, props) => {
  const {
    xValue,
    xAxisLabel,
    yValue,
    circleRadius,
    yAxisLabel,
    margin,
    width,
    height,
    data,
    color,
    cValue,
    selectedLegend,
    tipMouseover,
    tipMouseout
  } = props;
    
  const innerWidth = width - margin.left - margin.right -230;
  const innerHeight = height - margin.top - margin.bottom;
  
  const circles = g.merge(gEnter)
    .selectAll('circle').data(data);
  circles
    .enter().append('circle')
      .attr('cx', innerWidth / 2)
      .attr('cy', innerHeight / 2)
      .attr('r', 0)
  		.attr('opacity', 0.8)
    	.on('mouseover', tipMouseover)
      .on('mouseout', tipMouseout)
    .merge(circles)
    .transition().duration(1000)
    .delay((d, i) => i * 2)
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius)
      .attr('fill', d => color(cValue(d)));
  
  circles
    .merge(circles)
      .attr('opacity', d =>
        (!selectedLegend || selectedLegend === cValue(d))
          ? 0.8
          : 0.05
      )
    	.attr('r', d =>
        (selectedLegend === cValue(d))
          ? 2*circleRadius
          : circleRadius
     	);

};